@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2012 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -39,7 +39,7 @@ public:
     virtual void initUi();
 
 public Q_SLOTS:
-    virtual void markAllAsRead();
+//     virtual void markAllAsRead();
     void slotContextMenu(QWidget *w, const QPoint& pt);
 
 protected Q_SLOTS:
