@@ -1,7 +1,7 @@
 /*
 This file is part of Choqok, the KDE micro-blogging client
 
-Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+Copyright (C) 2008-2012 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -70,6 +70,7 @@ public:
     int order;            // 0: web, -1: natural
     Choqok::TimelineInfo *info;
     bool isClosable;
+    KIcon timelineIcon;
 };
 
 TimelineWidget::TimelineWidget(Choqok::Account* account, const QString &timelineName, QWidget* parent /*= 0*/)
@@ -114,11 +115,21 @@ QString TimelineWidget::timelineInfoName()
     return d->info->name;
 }
 
-QString TimelineWidget::timelineIcon()
+QString TimelineWidget::timelineIconName()
 {
     return d->info->icon;
 }
 
+void TimelineWidget::setTimelineIcon(const KIcon& icon)
+{
+    d->timelineIcon = icon;
+}
+
+KIcon& TimelineWidget::timelineIcon() const
+{
+    return d->timelineIcon;
+}
+
 void TimelineWidget::setTimelineName(const QString &type)
 {
     d->timelineName = type;
