@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2010-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2010-2012 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -66,10 +66,6 @@ FilterManager::~FilterManager()
 
 void FilterManager::slotAddNewPostWidget(Choqok::UI::PostWidget* newWidget)
 {
-//     if(!theAccount->inherits("TwitterApiAccount")){
-//         kDebug()<<"Not a TwitterApi like account";
-//         return;
-//     }
     postsQueue.enqueue(newWidget);
     if(state == Stopped){
         state = Running;
@@ -93,7 +89,9 @@ void FilterManager::startParsing()
 
 void FilterManager::parse(Choqok::UI::PostWidget* postToParse)
 {
-    if(!postToParse)
+    if( !postToParse ||
+        postToParse->currentPost().author.userName == postToParse->currentAccount()->username() ||
+        postToParse->isRead() )
         return;
 
     if( parseSpecialRules(postToParse) )
@@ -105,7 +103,7 @@ void FilterManager::parse(Choqok::UI::PostWidget* postToParse)
     foreach(Filter* filter, FilterSettings::self()->filters()) {
         if(filter->filterText().isEmpty())
             return;
-        if(filter->dontHideReplies() &&
+        if(filter->filterAction() == Filter::Remove && filter->dontHideReplies() &&
             (postToParse->currentPost().replyToUserName.compare(postToParse->currentAccount()->username(),
                                                                 Qt::CaseInsensitive) == 0 ||
              postToParse->currentPost().content.contains(QString("@%1").arg(postToParse->currentAccount()->username())))
@@ -130,47 +128,57 @@ void FilterManager::parse(Choqok::UI::PostWidget* postToParse)
     }
 }
 
-FilterManager::FilterAction FilterManager::filterText(const QString& textToCheck, Filter* filter)
+Filter::FilterAction FilterManager::filterText(const QString& textToCheck, Filter* filter)
 {
+    bool filtered = false;
     switch(filter->filterType()){
         case Filter::ExactMatch:
-            if(textToCheck == filter->filterText()){
-                kDebug()<<"ExactMatch: " << filter->filterText();
-                return Remove;
+            if(textToCheck.compare( filter->filterText(), Qt::CaseInsensitive) == 0){
+//                 kDebug()<<"ExactMatch: " << filter->filterText();
+                filtered = true;
             }
             break;
         case Filter::RegExp:
             if( textToCheck.contains(QRegExp(filter->filterText())) ){
-                kDebug()<<"RegExp: " << filter->filterText();
-                return Remove;
+//                 kDebug()<<"RegExp: " << filter->filterText();
+                filtered = true;
             }
             break;
         case Filter::Contain:
-            if( textToCheck.contains(filter->filterText()) ){
-                kDebug()<<"Contain: " << filter->filterText();
-                return Remove;
+            if( textToCheck.contains(filter->filterText(), Qt::CaseInsensitive) ){
+//                 kDebug()<<"Contain: " << filter->filterText();
+                filtered = true;
             }
             break;
         case Filter::DoesNotContain:
-            if( !textToCheck.contains(filter->filterText()) ){
-                kDebug()<<"DoesNotContain: " << filter->filterText();
-                return Remove;
+            if( !textToCheck.contains(filter->filterText(), Qt::CaseInsensitive) ){
+//                 kDebug()<<"DoesNotContain: " << filter->filterText();
+                filtered = true;
             }
             break;
         default:
-            return None;
             break;
     }
-    return None;
+    if(filtered)
+        return filter->filterAction();
+    else
+        return Filter::None;
 }
 
-void FilterManager::doFiltering(Choqok::UI::PostWidget* postToFilter, FilterManager::FilterAction action)
+void FilterManager::doFiltering(Choqok::UI::PostWidget* postToFilter, Filter::FilterAction action)
 {
+    QString css;
     switch(action){
-        case Remove:
-            kDebug()<<"Post filtered: "<<postToFilter->currentPost().content;
+        case Filter::Remove:
+            kDebug()<<"Post removed: "<<postToFilter->currentPost().content;
             postToFilter->close();
             break;
+        case Filter::Highlight:
+            css = postToFilter->styleSheet();
+            css.replace("border: 1px solid rgb(150,150,150)", "border: 2px solid rgb(255,0,0)");
+            postToFilter->setStyleSheet(css);
+            break;
+        case Filter::None:
         default:
             //Do nothing
             break;
